/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.2 Baustellensimulation
 * Copyright (C) 2007 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.simbaustelle.prognose;

import java.util.List;

/**
 * Allgemeine Schnittstelle zur Beschreibung des Berechnungszeitraums für eine
 * Baustellenprogenose.<br>
 * Die Klasse lisefert die Zeitpunkte, zu denen eine Berechnung erfolgen soll.
 *
 * @author BitCtrl Systems GmbH, Peuker
 */
public interface BerechnungsZeitRaumSchnittstelle {

	/**
	 * liefert den Endzeitpunkt des Zeitraums.
	 *
	 * @return den Zeitpunkt
	 */
	long getEndeZeitpunkt();

	/**
	 * liefert die Zeitpunkte für die Berechnung der Prognose.<br>
	 * Die Liste der Intervalle ergibt sich aus dem Startzeitpunkt, dem
	 * Endzeitpunkt und der vorgegebenen Schrittweite. Der Startzeitpunkt ist
	 * kein Ausführungszeitpunkt.
	 *
	 * @return die Berechnungszeitpunkte
	 */
	List<Long> getIntervalle();

	/**
	 * liefert die Schrittweite für die Intervalle des konkreten Berechnungszeitraums.
	 *
	 * @return die Schrittweite in Millisekunden
	 */
	long getSchrittweiteInMsec();
	
	/**
	 * liefert den Startzeitpunkt des Zeitraums.
	 *
	 * @return den Zeitpunkt
	 */
	long getStartZeitpunkt();

	/**
	 * ermittelt, ob der Zeitraum gültig ist, d.h. die Länge muss größer als 0
	 * sein.
	 *
	 * @return <code>true</code>, wenn er gültig ist
	 */
	boolean isValid();

	/**
	 * ermittelt, ob der Zeitraum ein Intervall enthält, über das eine Prognose
	 * erstellt werden kann.
	 *
	 * Der Startzeitpunkt kann identisch mit dem Endzeitpunkt sein, wenn die
	 * Simulation der Baustelle zu früh vor dem Beginn des Baustellenzeitraums
	 * oder nach dem Ende der Baustelle ausgeführt wird. Dann können keine
	 * Stauereignisse berechnet werden.
	 *
	 * @return <code>true</code>, wenn eine Prognose prinzipiell möglich ist
	 */
	boolean prognoseMoeglich();
}
